Rails.application.routes.draw do
  devise_for :accounts

  scope '/admin' do
    mount Ckeditor::Engine => '/ckeditor'
    resources :pages
    resources :settings, only: [:index, :edit, :update]
    resources :images, only: [:show, :edit, :update]
    resources :accounts
    resources :newsletters
    controller :newsletters do
      get 'newsletters/:id/send' => :sending, as: 'send_newsletter'
      get 'newsletters/:id/resend' => :resend, as: 'resend_newsletter'
    end
    resources :miners

    controller :admin do
      get '/' => :index, as: :admin_index
      patch 'links_pinned' => :links_pinned
    end

    controller :blocks do
      post 'blocks/apply' => :apply
      post 'blocks/cancel' => :cancel
      patch 'blocks/:id/' => :update, as: :update_block
      get 'blocks/:id/edit' => :edit
    end

    root 'pages#index', as: :admin
  end

  get '/' => 'front#index'
  get 'pages/:id' => 'front#page', as: :front_page

  get '/miners_activity/:name', to: 'front#miners_activity', as: 'miners_activity'
  get '/update_miner_activity/:name', to: 'front#update_miner_activity', as: 'update_miner_activity'

  root 'front#index'
end
